@@ -65,13 +65,11 @@ typedef struct
   MarkupTree *tree;
   guint dir_mode;
   guint file_mode;
-  guint try_merge : 1;
 } MarkupSource;
 
 static MarkupSource* ms_new     (const char   *root_dir,
                                  guint         dir_mode,
                                  guint         file_mode,
-                                 gboolean      try_merge,
                                  GConfLock    *lock);
 static void          ms_destroy (MarkupSource *source);
 
@@ -264,7 +262,6 @@ resolve_address (const char *address,
   char** address_flags;
   char** iter;
   gboolean force_readonly;
-  gboolean try_merge;
 
   root_dir = get_dir_from_address (address, err);
   if (root_dir == NULL)
@@ -289,7 +286,6 @@ resolve_address (const char *address,
     }
 
   force_readonly = FALSE;
-  try_merge = TRUE;
   
   address_flags = gconf_address_flags (address);  
   if (address_flags)
@@ -301,10 +297,6 @@ resolve_address (const char *address,
             {
               force_readonly = TRUE;
             }
-          else if (strcmp (*iter, "nomerge") == 0)
-            {
-              try_merge = FALSE;
-            }
 
           ++iter;
         }
@@ -393,12 +385,9 @@ resolve_address (const char *address,
       return NULL;
     }
   
-  if (try_merge && !(flags & GCONF_SOURCE_ALL_WRITEABLE))
-    try_merge = FALSE;
-
   /* Create the new source */
 
-  xsource = ms_new (root_dir, dir_mode, file_mode, try_merge, lock);
+  xsource = ms_new (root_dir, dir_mode, file_mode, lock);
 
   gconf_log (GCL_DEBUG,
              _("Directory/file permissions for XML source at root %s are: %o/%o"),
@@ -901,7 +890,6 @@ static MarkupSource*
 ms_new (const char* root_dir,
         guint       dir_mode,
         guint       file_mode,
-        gboolean    try_merge,
         GConfLock  *lock)
 {
   MarkupSource* ms;
@@ -920,12 +908,10 @@ ms_new (const char* root_dir,
 
   ms->dir_mode = dir_mode;
   ms->file_mode = file_mode;
-  ms->try_merge = try_merge;
   
   ms->tree = markup_tree_get (ms->root_dir,
                               ms->dir_mode,
-                              ms->file_mode,
-                              ms->try_merge);
+                              ms->file_mode);
   
   return ms;
 }
